#!/usr/bin/bash

# https://www.jianshu.com/p/14b9eccc0c0e

## 进入conda环境
# conda env list
conda activate snakemake
# snakemake --cores 1 data_output/set_Chromatin_Interaction.txt --forceall
# 输出
# rm data_output/*.Rdata
snakemake --cores 4 data_output/Mutations.Rdata
snakemake --cores 4 data_output/Cancer_Immunology.Rdata
snakemake --cores 4 data_output/Tumor_Metastasis.Rdata
snakemake --cores 4 data_output/ceRNA.Rdata
snakemake --cores 4 data_output/Chromatin_Interaction.Rdata
snakemake --cores 4 data_output/RNA_RNA_Interaction.Rdata
snakemake --cores 4 data_output/RNA_Protein_Interaction.Rdata
snakemake --cores 4 data_output/RNA_Histone_Modification.Rdata
snakemake --cores 4 data_output/RNA_Compound.Rdata
snakemake --cores 4 data_output/Tissue_Spatial_Expression.Rdata
snakemake --cores 4 data_output/Cancer_Functional_State.Rdata
snakemake --cores 4 data_output/Disease_Type.Rdata
snakemake --cores 4 data_output/m6A_Modification.Rdata
snakemake --cores 4 data_output/Experimental_Validated_Function.Rdata
snakemake --cores 4 data_output/Cell_Marker.Rdata
snakemake --cores 4 data_output/Conservation.Rdata
snakemake --cores 4 data_output/eQTL.Rdata
snakemake --cores 4 data_output/Exosome.Rdata
snakemake --cores 4 data_output/Inflammation.Rdata
snakemake --cores 4 data_output/SmORF.Rdata
snakemake --cores 4 data_output/Methylation_Pattern.Rdata
snakemake --cores 4 data_output/Gene_Perturbation.Rdata
snakemake --cores 4 data_output/Subcellular_Localization.Rdata
snakemake --cores 4 data_output/Survival.Rdata
snakemake --cores 4 data_output/Drug.Rdata
snakemake --cores 4 data_output/Transcription_Co_Factor.Rdata
snakemake --cores 4 data_output/Splicing_Events.Rdata
snakemake --cores 4 data_output/Chromatin_Regulators.Rdata

############ 大数据集合 ############

snakemake --cores 1 data_output/Transcription_Factor.Rdata
snakemake --cores 1 data_output/Enhancer.Rdata
snakemake --cores 1 data_output/Super_Enhancer.Rdata
snakemake --cores 1 data_output/Accessible_Chromatin.Rdata

# 主表
rm data_output/final_main.txt
snakemake --cores 1 data_output/final_main.txt
# 画流程图
snakemake --cores 1 --dag data_output/final_main.txt | dot -Tsvg > final.svg
# Class-LncRNA矩阵
rm data_output/final_class_lncRNA_*_matrix.txt
snakemake --cores 1 data_output/final_class_lncRNA_adjacency_matrix.txt
# final_class_summary
rm data_output/final_class_summary.txt
snakemake --cores 1 data_output/final_class_summary.txt

# idConvert
rm data_output/info_idConvert_human.txt
snakemake --cores 1 data_output/info_idConvert_human.txt
# annotation_information_human
rm data_output/info_annotation_information_human.txt
snakemake --cores 1 data_output/info_annotation_information_human.txt
# process
rm data_output/info_process.txt
snakemake --cores 1 data_output/info_process.txt
# class_info
snakemake --cores 1 data_output/info_class.txt --forceall
# class_subclass_info
# snakemake --cores 1 data_output/info_class_subclass.txt --forceall
# json/js
snakemake --cores 1 data_output/class_data.json --forceall
# 生成gmt文件
rm data_output/gmt_*.txt
python script/other/gmt.py
# 打包snakefile
zip -q -r LncSEA_snakemake.zip Snakefile main.sh final.svg \
script/Accessible_Chromatin \
script/class_subclass_info.py \
script/eQTL \
script/Super_Enhancer \
script/Cancer_Functional_State \
script/Class_Summary.py \
script/Exosome \
script/Survival \
script/Cancer_Immunology \
script/Conservation \
script/Experimental_Validated_Function \
script/RNA_Compound \
script/TCGA_filter_lnc.py \
script/Cell_Marker \
script/create_json.py \
script/Gene_Perturbation \
script/RNA_Histone_Modification \
script/Tissue_Spatial_Expression \
script/ceRNA \
script/create_rdata.R \
script/Inflammation \
script/RNA_Protein_Interaction \
script/Transcription_Co_Factor \
script/Chromatin_Interaction \
script/create_set.py \
script/m6A_Modification \
script/RNA_RNA_Interaction \
script/Transcription_Factor \
script/class_info.py \
script/Disease_Type \
script/main.py \
script/SmORF \
script/Tumor_Metastasis \
script/Class_LncRNA_Adjacency_Matrix.py \
script/Drug \
script/Methylation_Pattern \
script/Splicing_Events \
script/Chromatin_Regulators \
script/Class_LncRNA_Count_Matrix.py \
script/Enhancer \
script/Mutations \
script/Subcellular_Localization
# drop/truncate数据库所有表
# python script/other/database_clear.py -c "detail_Enhancer"
# 导入数据库(请先清空对应表)
python script/other/database_import.py -c "detail_Enhancer"

# 构建数据库索引
python script/other/database_add_index.py

# TCGA 表达谱
# snakemake --cores 1 data_output/example_gsva.txt --forceall

# TCGA 结直肠癌 差异表达分析
python script/other/diff.py

# 移动文件到网站 NHlcq123456@@
rsync --progress -avzhe 'ssh -p 22' data_output/{set,gmt}_*.txt root@bio.liclab.net:/var/www/html/LncSEAv2/public/download/
rsync --progress -avzhe 'ssh -p 22' data_output/*.Rdata root@bio.liclab.net:/var/www/html/LncSEAv2/analysis/lncRNASet/human/
rsync --progress -avzhe 'ssh -p 22' LncSEA_snakemake.zip root@bio.liclab.net:/var/www/html/LncSEAv2/public/download/
# cp data_output/example_gsva.txt /var/www/html/LncSEAv2/analysis/
# cp final.svg /var/www/html/LncSEAv2/public/img/
# cp LncSEA_snakemake.zip /var/www/html/LncSEAv2/public/download/
# rm -f /var/www/html/LncSEAv2/analysis/lncRNASet/human/*.Rdata && cp data_output/*.Rdata /var/www/html/LncSEAv2/analysis/lncRNASet/human/
# cp data_output/human.json /var/www/html/LncSEAv2/public/specie/
# cp data_output/class_data.json /var/www/html/LncSEAv2/public/
# 下载文件
# rm -f /var/www/html/LncSEAv2/public/download/{set,gmt}_*.txt && cp data_output/{set,gmt}_*.txt /var/www/html/LncSEAv2/public/download/
