import pandas as pd


def lnc_filter(data):
    data = data.dropna().drop_duplicates()
    lncrans = pd.read_csv("data/LncSEA+NONCODE+GENCODE.lnc.txt")
    lncrans = set(lncrans["LncRNA"])
    print("---------------Shape: ---------------", data.shape)
    data = data[data.LncRNA.apply(lambda x: x in lncrans)]
    print("---------------Shape: ---------------", data.shape)
    return data


def expand_row(data, col, split=","):
    r = data[col].str.split(split, expand=True)
    r = r.stack().reset_index(level=1, drop=True).dropna().rename(col)
    data = data.drop([col], axis=1).join(r)
    return data


pattern = {
    'bidirectional_promoter_lncRNA',
    'processed_transcript',
    'non_coding',
    'lincRNA',
    'antisense',
    '3prime_overlapping_ncRNA',
    'sense_intronic',
    'sense_overlapping',
}


def processing(row, on="left"):
    try:
        row = row.astype(str)
        Interaction1 = row[0] + ":" + row[1] + "-" + row[2]
        Interaction2 = row[3] + ":" + row[4] + "-" + row[5]
        gene1 = row[8].split(":")[1]
        gene_type1 = row[8].split(":")[2]
        gene2 = row[9].split(":")[1]
        gene_type2 = row[9].split(":")[2]
        Interaction_element1 = row[6].split("_")[0]
        Interaction_element2 = row[6].split("_")[1]
        if on == "left" and gene_type1 in pattern:
            return [
                gene2,
                gene1,
                gene_type2,
                gene_type1,
                Interaction2,
                Interaction1,
                Interaction_element2 + "_" + Interaction_element1,
            ]
        elif on == "right" and gene_type2 in pattern:
            return [
                gene1,
                gene2,
                gene_type1,
                gene_type2,
                Interaction1,
                Interaction2,
                Interaction_element1 + "_" + Interaction_element2,
            ]
    except:
        return None


def run(data_path, detail_path):
    ## OncoBase ##
    # OncoBase
    print("------------OncoBase------------")
    data = pd.read_csv(data_path[0], sep="\t", header=None)
    data_left = data.T.apply(lambda x: processing(x, "left")).T.dropna()
    print("left ............... final!")
    data_right = data.T.apply(lambda x: processing(x, "right")).T.dropna()
    print("right ............... final!")
    data = pd.concat([data_left, data_right], ignore_index=True)
    data.columns = [
        "Set",
        "LncRNA",
        "D1_GeneTypeA",
        "D2_GeneTypeB",
        "D3_InteractionA",
        "D4_InteractionB",
        "D5_Interaction_element_A_B",
    ]
    data = data.dropna().drop_duplicates()
    data["Sub_Class"] = "OncoBase"
    data["Class"] = "Chromatin_Interaction"
    data.to_csv(detail_path[0], index=False)


run(snakemake.input, snakemake.output)
