import pandas as pd


def lnc_filter(data):
    data = data.dropna().drop_duplicates()
    lncrans = pd.read_csv("data/LncSEA+NONCODE+GENCODE.lnc.txt")
    lncrans = set(lncrans["LncRNA"])
    print("---------------Shape: ---------------",data.shape)
    data = data[data.LncRNA.apply(lambda x:x in lncrans)]
    print("---------------Shape: ---------------",data.shape)
    return data

def expand_row(data,col,split=","):
    r = data[col].str.split(split,expand=True)
    r = r.stack().reset_index(level=1, drop=True).dropna().rename(col)
    data = data.drop([col],axis=1).join(r)
    return data

def run(data_path, detail_path):
    ## Super_Enhancer ##
    # Super_Enhancer
    print("-----------Super_Enhancer------------")
    se_target_gene = pd.read_csv(data_path[0],sep="\t")
    se_main = pd.read_csv(data_path[1],sep="\t")
    cell = pd.read_csv(data_path[2],sep="\t")
    data = pd.merge(se_target_gene,se_main,on="se_id")
    data = pd.merge(data,cell,on="cell_id")
    data = data.query("Species != 'Mouse'")
    data["Set"] = data["cell_id"] + "_" + data["cell_type"] + "_" + data["cell_name"]
    data["Version"] = "hg38"
    methods = {
        'se_gene_overlap': 'Overlap', 
        'se_gene_closest': 'Closest', 
        'se_gene_closest_active': 'Closest_active',
        'se_gene_proximal': 'Proximal', 
        'se_gene_lasso': 'JEME', 
        'se_gene_prestige': 'Prestige'
    }
    data["method"] = data["method"].map(methods.get)
    data = data[["Set","target_gene","se_chr","se_start","se_end","Version","method"]]
    data.columns = ["Set","LncRNA","D1_chr","D2_start","D3_end","Version","Sub_Class"]
    data = lnc_filter(data)
    data["Class"] = "Super_Enhancer"
    for i in methods:
        data.query(f"Sub_Class == '{methods[i]}'").to_csv(f"{detail_path[0]}_{methods[i]}.txt", index=False)

run(snakemake.input, snakemake.output)
