import pandas as pd


def lnc_filter(data):
    data = data.dropna().drop_duplicates()
    lncrans = pd.read_csv("data/LncSEA+NONCODE+GENCODE.lnc.txt")
    lncrans = set(lncrans["LncRNA"])
    print("---------------Shape: ---------------", data.shape)
    data = data[data.LncRNA.apply(lambda x: x in lncrans)]
    print("---------------Shape: ---------------", data.shape)
    return data


def expand_row(data, col, split=","):
    r = data[col].str.split(split, expand=True)
    r = r.stack().reset_index(level=1, drop=True).dropna().rename(col)
    data = data.drop([col], axis=1).join(r)
    return data


def run(data_path, detail_path):
    ## GWAS_cis ##
    # GWAS_cis
    print("-----------GWAS_cis------------")
    data = pd.read_csv(data_path[0], encoding="gbk")
    data = data[data["Sub_Class"] == "GWAS_Cis"]
    data = data[
        [
            "Set",
            "LncRNA",
            "D1_gene_id",
            "D2_tag_SNP",
            "D3_LD",
            "D4_SNP_id",
            "D5_t_stat",
            "D6_p_value",
            "D7_FDR",
            "D8_beta",
            "D9_r",
            "D10_Traits",
            "D11_SNP_position",
            "D12_Version",
        ]
    ]
    data.columns = [
        "Set",
        "LncRNA",
        "D1_gene_id",
        "D2_tag_SNP",
        "D3_LD",
        "D4_SNP_id",
        "D5_t_stat",
        "D6_p_value",
        "D7_FDR",
        "D8_beta",
        "D9_r",
        "D10_Traits",
        "D11_SNP_position",
        "D12_Version",
    ]
    data = lnc_filter(data)
    data["Sub_Class"] = "GWAS_cis"
    data["Class"] = "eQTL"
    data.to_csv(detail_path[0], index=False)


run(snakemake.input, snakemake.output)
